==> meko-0.3.0.tar.gz: meko-0.3.0/src/whois_info.h <==
/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * whois_info.h
 * -- 
 * $Id: whois_info.h,v 1.1 2001/06/07 12:33:30 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#ifndef _MEKO_WHOIS_INFO_H
#define _MEKO_WHOIS_INFO_H

/* Required includes */
#include <glib.h>
#include <time.h>
#include "say2_server.h"

/* Structure to hold all possible fields of a client-info (whois reply)
 * command
 */
typedef struct _whois_info WhoisInfo;
struct _whois_info {
	/* "user", "channel", "all" */
	gchar *type;

	/* Various string details */
	gchar *id;
	gchar *nick;
	gchar *email;
	gchar *host;
	gchar *address;
	gchar *tagline;
	gchar *client;

	/* True or false */
	gboolean offline;

	/* "active", "busy", "away", "idle", a message and when it was
	 * last changed
	 */
	gchar  *mode;
	gchar  *status;
	time_t  status_time;

	/* Times */
	time_t login;
	time_t idle;
	time_t last_login;
	time_t last_logout;

	/* Icon data */
	char *icon;
};

/* Create and Free a WhoisInfo structure */
WhoisInfo *whois_info_new(void);
void       whois_info_free(WhoisInfo *);
void       whois_info_free_list(GSList *);

/* Create a WhoisInfo structure from a client-info Enaml Block */
WhoisInfo *whois_info_new_from_block(const EnamlBlock *);

/* Output a WhoisInfo structure in usual whois format */
void whois_info_dump(Say2Server *, WhoisInfo *);

/* Output a list of WhoisInfo structures in whom format */
void whois_info_dump_list(Say2Server *, GSList *, glong, glong);

/* Returns a string textually representing a timespan */
gchar *whois_timespan_str(time_t);

#endif /* !_MEKO_WHOIS_INFO_H */

==> meko-0.5.0.tar.gz: meko-0.5.0/src/whois_info.h <==
/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * whois_info.h
 * -- 
 * $Id: whois_info.h,v 1.3 2001/06/13 11:53:40 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#ifndef _MEKO_WHOIS_INFO_H
#define _MEKO_WHOIS_INFO_H

/* Required includes */
#include <glib.h>
#include <time.h>
#include "say2_types.h"

/* Structure to hold all possible fields of a client-info (whois reply)
 * command.  This has far more information than we'd ever want to keep
 * in memory, which is why it's a separate structure to Say2Client.
 */
typedef struct _whois_info WhoisInfo;
struct _whois_info {
	/* "user", "channel", "all" */
	gchar *type;

	/* Various string details */
	gchar *id;
	gchar *nick;
	gchar *email;
	gchar *host;
	gchar *address;
	gchar *tagline;
	gchar *client;

	/* True or false */
	gboolean offline;

	/* "active", "busy", "away", "idle", a message and when it was
	 * last changed
	 */
	gchar  *status_mode;
	gchar  *status_msg;
	time_t  status_time;

	/* Times */
	time_t login;
	time_t idle;
	time_t last_login;
	time_t last_logout;

	/* Icon data */
	char *icon;
};

/* Create and Free a WhoisInfo structure */
WhoisInfo *whois_info_new(void);
void       whois_info_free(WhoisInfo *);
void       whois_info_free_list(GSList *);

/* Create a WhoisInfo structure from a client-info Enaml Block */
WhoisInfo *whois_info_new_from_block(const EnamlBlock *);

/* Output a WhoisInfo structure in either whois or whom format */
void whois_info_dump(Say2Server *, WhoisInfo *);
void whois_info_dump_list(Say2Server *, GSList *, glong, glong);

/* Returns a string textually representing a timespan */
gchar *whois_timespan_str(time_t);

#endif /* !_MEKO_WHOIS_INFO_H */
